@@ -7,7 +7,7 @@ FIELDS_TO_EXPORT = [
     'to_address',
     'amount',
     'token_type'
-    'token_ids'
+    'token_id'
     'transaction_hash',
     'log_index',
     'block_number',
@@ -18,10 +18,10 @@ FIELDS_TO_EXPORT = [
 def token_transfers_v2_item_exporter(token_transfer_output, converters=()):
     return CompositeItemExporter(
         filename_mapping={
-            'token_transfer': token_transfer_output
+            'token_transfer_v2': token_transfer_output
         },
         field_mapping={
-            'token_transfer': FIELDS_TO_EXPORT
+            'token_transfer_v2': FIELDS_TO_EXPORT
         },
         converters=converters
     )
